//__lib__ lib_common
'use strict';

SHINKEN.TOOLS.UpdateAtComponent           = function ( dom_element ) {
    this.dom_element = dom_element;
    this.dom_element_date = this.dom_element.querySelector(".shinken-time-label");
};
SHINKEN.TOOLS.UpdateAtComponent.prototype = {
    
    //********************************************  INIT  *****************************************************//
    
    //********************************************  GETTER SETTER  *****************************************************//
    setLastComputeDate: function ( to_set ) {
        if ( !to_set ) {
            this.dom_element_date.innerHTML = _( 'service_weather.generate_at.generation_in_progress', [DICTIONARY_COMMON_UI] );
        }
        else {
            this.dom_element_date.innerHTML = DATE_TIME.FORMAT.get_time_from_timestamp( to_set );
        }
    }
    //********************************************  HTML  *****************************************************//
    //********************************************  COMPUTE  *****************************************************//
    //********************************************  EVENT REFRESH  *****************************************************//
    //********************************************  OTHERS  *****************************************************//
};
SHINKEN.TOOLS.CLASS.addPrototype( SHINKEN.TOOLS.UpdateAtComponent, SHINKEN.TOOLS.InterfaceRefreshComponent );

